@@ -1,7 +1,7 @@
 #' Provide a succinct summary of an object
 #'
 #' @description
-#' \Sexpr[results=rd, stage=render]{pillar:::lifecycle("questioning")}
+#' `r lifecycle::badge("questioning")`
 #'
 #' @description
 #' `type_sum()` gives a brief summary of object type. Objects that commonly
@@ -19,7 +19,9 @@
 #'   and variants have been implemented.
 #'
 #' @export
-type_sum <- function(x) UseMethod("type_sum")
+type_sum <- function(x) {
+  UseMethod("type_sum")
+}
 
 #' @export
 type_sum.ordered <- function(x) {
@@ -35,10 +37,7 @@ type_sum.factor <- function(x) {
 
 #' @export
 type_sum.default <- function(x) {
-  if (is.object(x)) return(vctrs::vec_ptype_abbr(x))
-  # r-lib/vctrs#323:
-  if (typeof(x) == "complex") return("cpl")
-  if (vec_is(x)) return(vctrs::vec_ptype_abbr(x))
+  if (is.object(x) || vctrs::vec_is(x)) return(vctrs::vec_ptype_abbr(x))
 
   switch(typeof(x),
     builtin = ,
@@ -56,23 +55,15 @@ type_sum.default <- function(x) {
   )
 }
 
-# vec_is() needs vctrs > 0.1.0
-# Defined in .onLoad()
-vec_is <- function(...) {
-  vctrs::vec_is(...)
-}
-
-compat_vec_is <- function(x) {
-  is_vector(x)
-}
-
-vec_ptype_abbr.pillar_empty_col <- function(x) {
+# Registered in .onLoad()
+vec_ptype_abbr.pillar_empty_col <- function(x, ...) {
   vctrs::vec_ptype_abbr(x[[1]])
 }
 
 #' @description
-#' `obj_sum()` also includes the size of the object if `is_vector_s3()`
+#' `obj_sum()` also includes the size of the object if `vctrs::vec_is()`
 #' is `TRUE`.
+#' It should always return a string (a character vector of length one).
 #'
 #' @keywords internal
 #' @examples
@@ -83,21 +74,13 @@ vec_ptype_abbr.pillar_empty_col <- function(x) {
 #' obj_sum(mean)
 #' @rdname type_sum
 #' @export
-obj_sum <- function(x) UseMethod("obj_sum")
+obj_sum <- function(x) {
+  UseMethod("obj_sum")
+}
 
 #' @export
 obj_sum.default <- function(x) {
-  paste0(type_sum(x), size_sum(x))
-}
-
-#' @export
-obj_sum.list <- function(x) {
-  map_chr(x, obj_sum.default)
-}
-
-#' @export
-obj_sum.POSIXlt <- function(x) {
-  rep("POSIXlt", length(x))
+  paste_with_space_if_needed(type_sum(x), size_sum(x))
 }
 
 #' @export
@@ -105,20 +88,27 @@ obj_sum.AsIs <- function(x) {
   paste0("I(", obj_sum(remove_as_is_class(x)), ")")
 }
 
-#' @export
+#' @description
+#' `size_sum()` is called by `obj_sum()` to format the size of the object.
+#' It should always return a string (a character vector of length one),
+#' it can be an empty string `""` to omit size information,
+#' this is what the default method does for scalars.
+#'
+#' @keywords internal
+#' @examples
+#'
+#' size_sum(1:10)
+#' size_sum(trees)
+#' size_sum(Titanic)
 #' @rdname type_sum
-is_vector_s3 <- function(x) UseMethod("is_vector_s3")
 #' @export
-is_vector_s3.ordered <- function(x) TRUE
+size_sum <- function(x) {
+  UseMethod("size_sum")
+}
+
 #' @export
-is_vector_s3.factor <- function(x) TRUE
-#' @export
-is_vector_s3.Date <- function(x) TRUE
-#' @export
-is_vector_s3.POSIXct <- function(x) TRUE
-#' @export
-is_vector_s3.difftime <- function(x) TRUE
-#' @export
-is_vector_s3.data.frame <- function(x) TRUE
-#' @export
-is_vector_s3.default <- function(x) !is.object(x) && is_vector(x)
+size_sum.default <- function(x) {
+  if (!vctrs::vec_is(x)) return("")
+
+  paste0("[", dim_desc(x), "]")
+}
